==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/CategorySeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningCategoryStyleEventArgsDescriptionMetadata } from "./AssigningCategoryStyleEventArgsDescriptionMetadata";
import { AssigningCategoryMarkerStyleEventArgsDescriptionMetadata } from "./AssigningCategoryMarkerStyleEventArgsDescriptionMetadata";
import { MarkerSeriesDescriptionMetadata } from "./MarkerSeriesDescriptionMetadata";
/**
 * @hidden
 */
var CategorySeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(CategorySeriesDescriptionMetadata, _super);
    function CategorySeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CategorySeriesDescriptionMetadata.b = function (a) {
        if (CategorySeriesDescriptionMetadata.a == null) {
            CategorySeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CategorySeriesDescriptionMetadata.c(CategorySeriesDescriptionMetadata.a);
        }
        if (a.j(CategorySeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(CategorySeriesDescriptionMetadata.a);
        AssigningCategoryStyleEventArgsDescriptionMetadata.d(a);
        AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.d(a);
    };
    CategorySeriesDescriptionMetadata.c = function (a) {
        MarkerSeriesDescriptionMetadata.c(a);
        a.item("IsCustomCategoryStyleAllowed", "Boolean");
        a.item("IsCustomCategoryMarkerStyleAllowed", "Boolean");
        a.item("UseHighMarkerFidelity", "Boolean");
        a.item("TransitionInMode", "ExportedType:string:CategoryTransitionInMode");
        a.item("TransitionInMode@names", "Auto;FromZero;SweepFromLeft;SweepFromRight;SweepFromTop;SweepFromBottom;SweepFromCenter;AccordionFromLeft;AccordionFromRight;AccordionFromTop;AccordionFromBottom;Expand;SweepFromCategoryAxisMinimum;SweepFromCategoryAxisMaximum;SweepFromValueAxisMinimum;SweepFromValueAxisMaximum;AccordionFromCategoryAxisMinimum;AccordionFromCategoryAxisMaximum;AccordionFromValueAxisMinimum;AccordionFromValueAxisMaximum");
        a.item("IsTransitionInEnabled", "Boolean");
        a.item("AssigningCategoryStyleRef", "EventRef::assigningCategoryStyle");
        a.item("AssigningCategoryMarkerStyleRef", "EventRef::assigningCategoryMarkerStyle");
    };
    CategorySeriesDescriptionMetadata.d = function (a) {
        CategorySeriesDescriptionMetadata.b(a);
        a.z("CategorySeries", CategorySeriesDescriptionMetadata.a);
    };
    CategorySeriesDescriptionMetadata.$t = markType(CategorySeriesDescriptionMetadata, 'CategorySeriesDescriptionMetadata');
    CategorySeriesDescriptionMetadata.a = null;
    return CategorySeriesDescriptionMetadata;
}(Base));
export { CategorySeriesDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/CategorySeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningCategoryStyleEventArgsDescriptionMetadata } from "./AssigningCategoryStyleEventArgsDescriptionMetadata";
import { AssigningCategoryMarkerStyleEventArgsDescriptionMetadata } from "./AssigningCategoryMarkerStyleEventArgsDescriptionMetadata";
import { MarkerSeriesDescriptionMetadata } from "./MarkerSeriesDescriptionMetadata";
/**
 * @hidden
 */
var CategorySeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(CategorySeriesDescriptionMetadata, _super);
    function CategorySeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CategorySeriesDescriptionMetadata.b = function (a) {
        if (CategorySeriesDescriptionMetadata.a == null) {
            CategorySeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CategorySeriesDescriptionMetadata.c(CategorySeriesDescriptionMetadata.a);
        }
        if (a.k(CategorySeriesDescriptionMetadata.a)) {
            return;
        }
        a.aa(CategorySeriesDescriptionMetadata.a);
        AssigningCategoryStyleEventArgsDescriptionMetadata.d(a);
        AssigningCategoryMarkerStyleEventArgsDescriptionMetadata.d(a);
    };
    CategorySeriesDescriptionMetadata.c = function (a) {
        MarkerSeriesDescriptionMetadata.c(a);
        a.item("IsCustomCategoryStyleAllowed", "Boolean");
        a.item("IsCustomCategoryMarkerStyleAllowed", "Boolean");
        a.item("UseHighMarkerFidelity", "Boolean");
        a.item("TransitionInMode", "ExportedType:string:CategoryTransitionInMode");
        a.item("TransitionInMode@names", "Auto;FromZero;SweepFromLeft;SweepFromRight;SweepFromTop;SweepFromBottom;SweepFromCenter;AccordionFromLeft;AccordionFromRight;AccordionFromTop;AccordionFromBottom;Expand;SweepFromCategoryAxisMinimum;SweepFromCategoryAxisMaximum;SweepFromValueAxisMinimum;SweepFromValueAxisMaximum;AccordionFromCategoryAxisMinimum;AccordionFromCategoryAxisMaximum;AccordionFromValueAxisMinimum;AccordionFromValueAxisMaximum");
        a.item("IsTransitionInEnabled", "Boolean");
        a.item("AssigningCategoryStyleRef", "EventRef::assigningCategoryStyle");
        a.item("AssigningCategoryMarkerStyleRef", "EventRef::assigningCategoryMarkerStyle");
    };
    CategorySeriesDescriptionMetadata.d = function (a) {
        CategorySeriesDescriptionMetadata.b(a);
        a.ab("CategorySeries", CategorySeriesDescriptionMetadata.a);
    };
    CategorySeriesDescriptionMetadata.$t = markType(CategorySeriesDescriptionMetadata, 'CategorySeriesDescriptionMetadata');
    CategorySeriesDescriptionMetadata.a = null;
    return CategorySeriesDescriptionMetadata;
}(Base));
export { CategorySeriesDescriptionMetadata };
